@@ -5,6 +5,8 @@ import os
 import threading
 import time
 import base64
+import pandas
+
 from functools import wraps
 
 from utils import filex
@@ -19,6 +21,12 @@ def _json_serialize(data):
             'type': 'bytes',
             'data': base64.b64encode(data).decode('ascii'),
         }
+    if isinstance(data, pandas.DataFrame):
+        return {
+            'type': 'pandas.DataFrame',
+            'data': data.to_dict(),
+        }
+
     return {
         'type': None,
         'data': data,
@@ -30,6 +38,8 @@ def _json_deserialize(data):
     data_data = data['data']
     if data_type == 'bytes':
         return base64.b64decode(data_data)
+    if data_type == 'pandas.DataFrame':
+        return pandas.DataFrame.from_dict(data_data)
     return data_data
 
 
